@@ -18,6 +18,7 @@
 #include <queue>
 #include <limits>
 #include <map>
+#include <random>
 
 #include <promod3/core/graph_minimizer.hh>
 #include <promod3/core/tree.hh>
@@ -25,9 +26,6 @@
 #include <promod3/core/enumerator.hh>
 #include <promod3/core/message.hh>
 
-#include <boost/random/mersenne_twister.hpp>
-#include <boost/random/uniform_01.hpp>
-
 
 namespace{
 
@@ -618,14 +616,14 @@ struct SolutionSelector {
                                      n(num_solutions.size()),
                                      n_solutions(num_solutions),
                                      rng(random_seed),
-                                     zeroone(rng) { }
+                                     zeroone(0.0, 1.0) { }
 
   int SelectNode() {
-    return static_cast<int>(zeroone() * n);
+    return std::max(0, std::min(n-1, static_cast<int>(zeroone(rng) * n)));
   }
 
   int SelectSolution(int node_idx) {
-    return static_cast<int>(zeroone() * n_solutions[node_idx]);
+    return std::max(0, std::min(n_solutions[node_idx]-1, static_cast<int>(zeroone(rng) * n_solutions[node_idx])));
   }
 
   void InitSolutionSelection(std::vector<int>& current_solution) {
@@ -636,13 +634,13 @@ struct SolutionSelector {
   }
 
   Real GetRandomNumber() {
-    return zeroone();
+    return zeroone(rng);
   }
 
   int n;
   std::vector<int> n_solutions;
-  boost::mt19937 rng;
-  boost::uniform_01<boost::mt19937&> zeroone;
+  std::mt19937 rng;
+  std::uniform_real_distribution<> zeroone;
 };
 
 } // anon ns
