@@ -480,8 +480,9 @@ void TorsionSampler::UpdateDistributions() {
 
   //fill phi/psi stuff
   for(uint i = 0; i < num_histograms; ++i){
-    distributions_[i] = boost::random::discrete_distribution<int,Real>(histogram_[i].begin(),histogram_[i].end());
-    probabilities_[i] = distributions_[i].probabilities();
+    distributions_[i] = std::discrete_distribution<>(histogram_[i].begin(),histogram_[i].end());
+    std::vector<double> p = distributions_[i].probabilities();
+    probabilities_[i].assign(p.begin(), p.end());
   }
 
   conditional_probabilities_ = false; 
@@ -523,7 +524,7 @@ void TorsionSampler::UpdateConditionalDistributions() {
     for(int j = 0; j < bins_per_dimension_; ++j){
       std::vector<int>::iterator b = histogram_[i].begin() + j * bins_per_dimension_;
       std::vector<int>::iterator e = histogram_[i].begin() + (j + 1) * bins_per_dimension_;
-      distributions_cond_psi_[i][j] = boost::random::discrete_distribution<int,Real>(b,e);
+      distributions_cond_psi_[i][j] = std::discrete_distribution<>(b,e);
     }
   }
 
@@ -535,7 +536,7 @@ void TorsionSampler::UpdateConditionalDistributions() {
       for(int k = 0; k < bins_per_dimension_; ++k){
         temp[k] = histogram_[i][j + k * bins_per_dimension_];
       }
-      distributions_cond_phi_[i][j] = boost::random::discrete_distribution<int,Real>(temp.begin(),temp.end());
+      distributions_cond_phi_[i][j] = std::discrete_distribution<>(temp.begin(),temp.end());
     }
   } 
 
