@@ -238,9 +238,23 @@ void CompareFullSimulation(const AllAtomPositions& all_pos,
   std::vector<uint> mapping = GetMapping(sim_ref->GetEntity(), mm_sim);
   ost::mol::AtomHandleList atoms = sim_ref->GetEntity().GetAtomList();
   for (uint i = 0; i < pos_ref.size(); ++i) {
-    BOOST_CHECK(geom::Distance(pos[mapping[i]], pos_ref[i]) < 1e-5);
-    BOOST_CHECK(geom::Distance(vel[mapping[i]], vel_ref[i]) < 1e-5);
-    BOOST_CHECK(geom::Distance(forces[mapping[i]], forces_ref[i]) < 1e-3);
+    // positions
+    BOOST_CHECK_SMALL(std::abs(pos[mapping[i]][0]-pos_ref[i][0]), static_cast<Real>(1e-3)); // x
+    BOOST_CHECK_SMALL(std::abs(pos[mapping[i]][1]-pos_ref[i][1]), static_cast<Real>(1e-3)); // y
+    BOOST_CHECK_SMALL(std::abs(pos[mapping[i]][2]-pos_ref[i][2]), static_cast<Real>(1e-3)); // z
+
+    // forces
+    BOOST_CHECK_SMALL(std::abs(forces[mapping[i]][0]-forces_ref[i][0]), static_cast<Real>(1e-1)); // x
+    BOOST_CHECK_SMALL(std::abs(forces[mapping[i]][1]-forces_ref[i][1]), static_cast<Real>(1e-1)); // y
+    BOOST_CHECK_SMALL(std::abs(forces[mapping[i]][2]-forces_ref[i][2]), static_cast<Real>(1e-1)); // z
+
+    // velocities are expected to be 0.0
+    BOOST_CHECK_SMALL(vel[mapping[i]][0], static_cast<Real>(1e-5)); // x
+    BOOST_CHECK_SMALL(vel[mapping[i]][1], static_cast<Real>(1e-5)); // y
+    BOOST_CHECK_SMALL(vel[mapping[i]][2], static_cast<Real>(1e-5)); // z
+    BOOST_CHECK_SMALL(vel_ref[i][0], static_cast<Real>(1e-5)); // x
+    BOOST_CHECK_SMALL(vel_ref[i][1], static_cast<Real>(1e-5)); // y
+    BOOST_CHECK_SMALL(vel_ref[i][2], static_cast<Real>(1e-5)); // z
   }
 
   // check mm_sim features (NOTE: DIFFs non-zero but that's expected...)
