@@ -28,6 +28,7 @@ void export_score_container();
 void export_scoring_weights();
 void export_SidechainReconstructor();
 void export_motif_finder();
+void export_afdb();
 
 BOOST_PYTHON_MODULE(_modelling)
 {
@@ -43,4 +44,5 @@ BOOST_PYTHON_MODULE(_modelling)
   export_scoring_weights();
   export_SidechainReconstructor();
   export_motif_finder();
+  export_afdb();
 }
