@@ -13,16 +13,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include <random>
 
 #include <promod3/modelling/ccd.hh>
 #include <promod3/core/runtime_profiling.hh>
 #include <promod3/core/geom_base.hh>
 
-#include <boost/random/mersenne_twister.hpp>
-#include <boost/random/variate_generator.hpp>
-#include <boost/random/uniform_real_distribution.hpp>
-#include <boost/random/uniform_int.hpp>
-
 namespace promod3 { namespace modelling {
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -413,8 +409,8 @@ bool CCD::GetConstrainedCloseRotations_(geom::Vec3* positions, Real* rot_phi,
   const geom::Vec3 * positions_end = positions + 3*num_residues;
   geom::Vec3 * actual_positions = positions + 3*last_idx;
   // fresh RNG each time (ensures reproducibility!)
-  boost::mt19937 rng(random_seed_);
-  boost::uniform_01<boost::mt19937&> zeroone(rng);
+  std::mt19937 rng(random_seed_);
+  std::uniform_real_distribution<> zeroone(0.0, 1.0);
 
   // variables for all the math below
   Real d_phi, d_psi, prob_ratio;
@@ -514,7 +510,7 @@ bool CCD::GetConstrainedCloseRotations_(geom::Vec3* positions, Real* rot_phi,
       }
 
       // rotate?
-      if (prob_ratio > zeroone()) {
+      if (prob_ratio > zeroone(rng)) {
         const bool apply_phi = (res_index != 0 && std::abs(d_phi) > Real(1e-6));
         const bool apply_psi = (res_index != last_idx &&
                                 std::abs(d_psi) > Real(1e-6));
