@@ -399,7 +399,7 @@ void MergeMHandle(const ModellingHandle& source_mhandle,
     throw promod3::Error("start_resnum must be smaller or equal end_resnum!");
   }
 
-  const String& seqres = source_mhandle.seqres[source_chain_idx].GetString();
+  String seqres = source_mhandle.seqres[source_chain_idx].GetString();
 
   if(end_resnum > seqres.size()){
     throw promod3::Error("end_resnum is too big for the underlying SEQRES of "
@@ -982,6 +982,7 @@ void AddRawChain(const seq::AlignmentHandle& aln,
   }
   
   ChainHandle chain=edi.InsertChain(chain_name);
+  edi.SetChainType(chain, ost::mol::CHAINTYPE_POLY_PEPTIDE_L);
 
   // we enforce res. numbering for target to start at 1
   int res_num = 0;
