@@ -172,20 +172,29 @@ struct InitialHits{
 struct Accumulator{
 
   Accumulator(const promod3::modelling::MotifQuery& query, 
-              Real coverage_thresh) {
+              Real coverage_thresh, int fix_thresh) {
 
     int n = 0;
     for(uint i = 0; i < query.GetN(); ++i) {
       range_start.push_back(n);
-      uint32_t query_size = query.GetQuerySize(i);
-      uint32_t n_triangles = query.GetNTriangles(i);
-      uint16_t thresh = std::ceil((query_size-3) * coverage_thresh);
-      for(uint j = 0; j < n_triangles; ++j) {
-        thresholds.push_back(thresh);
-      }
-      n += n_triangles;
+      n += query.GetNTriangles(i);
     }
     accumulator.assign(n, 0);
+
+    if(fix_thresh < 0) {
+      // default: thresholds depend on sizes of query
+      for(uint i = 0; i < query.GetN(); ++i) {
+        uint32_t query_size = query.GetQuerySize(i);
+        uint32_t n_triangles = query.GetNTriangles(i);
+        uint16_t thresh = std::ceil((query_size-3) * coverage_thresh);
+        for(uint j = 0; j < n_triangles; ++j) {
+          thresholds.push_back(thresh);
+        }
+      }
+    } else {
+      // assign fix thresh for each triangle
+      thresholds.assign(n, fix_thresh);
+    }
   }
 
 
@@ -416,9 +425,9 @@ void GetInitialAlignment(const promod3::core::EMat3X& query_pos,
 bool RefineInitialHit(const promod3::modelling::MotifQuery& query,  
                       const promod3::core::EMat3X& target_pos, 
                       const std::vector<int>& target_flags,
-                      Real dist_thresh, Real refine_thresh, int query_idx, 
-                      int query_triangle_idx, int target_p1, int target_p2, 
-                      int target_p3, geom::Mat4& mat, 
+                      Real dist_thresh, Real refine_thresh, bool swap_thresh,
+                      int query_idx, int query_triangle_idx, int target_p1,
+                      int target_p2, int target_p3, geom::Mat4& mat, 
                       std::vector<std::pair<int, int> >& alignment) {
 
   // the query is only available as geom::Vec3List. This makes sense from a 
@@ -527,8 +536,14 @@ bool RefineInitialHit(const promod3::modelling::MotifQuery& query,
   }
 
   // check whether enough positions are superposed
-  if(static_cast<Real>(alignment.size()) / query_n < refine_thresh) {
-    return false;
+  if(swap_thresh) {
+    if(static_cast<Real>(alignment.size()) / target_pos.cols() < refine_thresh) {
+      return false;
+    }
+  } else {
+    if(static_cast<Real>(alignment.size()) / query_n < refine_thresh) {
+      return false;
+    }
   }
 
   // chain together the final transformation matrix
@@ -546,7 +561,7 @@ void RefineInitialHits(const InitialHits& initial_hits,
                        const promod3::modelling::MotifQuery& query,
                        const promod3::core::EMat3X& target_pos, 
                        const std::vector<int>& flags, Real dist_thresh,
-                       Real refine_thresh,
+                       Real refine_thresh, bool swap_thresh,
                        std::vector<promod3::modelling::MotifMatch>& results) {
 
 
@@ -562,9 +577,9 @@ void RefineInitialHits(const InitialHits& initial_hits,
     for(auto it = initial_hits.initial_hits[query_idx].begin();
         it != initial_hits.initial_hits[query_idx].end(); ++it) {
       if(RefineInitialHit(query, target_pos, flags, dist_thresh, 
-                          refine_thresh, query_idx, it->triangle_idx, 
-                          it->target_p1, it->target_p2, it->target_p3, 
-                          mat, aln)) {
+                          refine_thresh, swap_thresh, query_idx,
+                          it->triangle_idx,  it->target_p1, it->target_p2,
+                          it->target_p3, mat, aln)) {
         // only add the result if its unique
         bool already_there = false;
         for(uint res_idx = 0; res_idx < query_results.size(); ++res_idx) {
@@ -1302,7 +1317,8 @@ std::vector<MotifMatch> FindMotifs(const MotifQuery& query,
                                    Real hash_thresh, 
                                    Real distance_thresh,
                                    Real refine_thresh,
-                                   const std::vector<int>& flags) {
+                                   const std::vector<int>& flags,
+                                   bool swap_thresh) {
 
   promod3::core::ScopedTimerPtr prof = promod3::core::StaticRuntimeProfiler::StartScoped(
                                 "FindMotifs::FindMotifs", 2);
@@ -1345,7 +1361,11 @@ std::vector<MotifMatch> FindMotifs(const MotifQuery& query,
 
   // fetch hash map and setup accumulator
   const MotifHasherMap& map = query.data_->map;
-  Accumulator accumulator(query, hash_thresh);
+  int acc_thresh = -1;
+  if(swap_thresh) {
+    acc_thresh = std::ceil((n_target-3) * hash_thresh);
+  }
+  Accumulator accumulator(query, hash_thresh, acc_thresh);
     
   for(int p1 = 0; p1 < n_target; ++p1) {
     for(int p2 = p1+1; p2 < n_target; ++p2) {
@@ -1421,7 +1441,7 @@ std::vector<MotifMatch> FindMotifs(const MotifQuery& query,
   }
 
   RefineInitialHits(initial_hits, query, eigen_positions, flags, 
-                    distance_thresh, refine_thresh, results);
+                    distance_thresh, refine_thresh, swap_thresh, results);
 
   return results;
 }
